@@ -85,6 +85,14 @@ guint64              soup_connection_get_id                     (SoupConnection
 GSocketAddress      *soup_connection_get_remote_address         (SoupConnection *conn);
 SoupHTTPVersion      soup_connection_get_negotiated_protocol    (SoupConnection *conn);
 gboolean             soup_connection_is_reusable                (SoupConnection *conn);
+GThread             *soup_connection_get_owner                  (SoupConnection *conn);
+
+void soup_connection_set_http2_initial_window_size        (SoupConnection *conn,
+                                                           int             window_size);
+int  soup_connection_get_http2_initial_window_size        (SoupConnection *conn);
+void soup_connection_set_http2_initial_stream_window_size (SoupConnection *conn,
+                                                           int             window_size);
+int  soup_connection_get_http2_initial_stream_window_size (SoupConnection *conn);
 
 G_END_DECLS
 
